==> node-bunyan_2.0.4+~cs4.4.2.orig.tar.gz: node-bunyan-2.0.4/test/cycles.test.js <==
/*
 * Copyright 2020 Trent Mick.
 *
 * Make sure cycles are safe.
 */

var Logger = require('../lib/bunyan.js');

// node-tap API
if (require.cache[__dirname + '/tap4nodeunit.js'])
        delete require.cache[__dirname + '/tap4nodeunit.js'];
var tap4nodeunit = require('./tap4nodeunit.js');
var after = tap4nodeunit.after;
var before = tap4nodeunit.before;
var test = tap4nodeunit.test;


var Stream = require('stream').Stream;
var outstr = new Stream;
outstr.writable = true;
var output = [];
outstr.write = function (c) {
    output.push(JSON.parse(c + ''));
};
outstr.end = function (c) {
    if (c) this.write(c);
    this.emit('end');
};

var expect =
        [
            {
                'name': 'blammo',
                'level': 30,
                'msg': 'bango { bang: \'boom\', KABOOM: [Circular] }',
                'v': 0
            },
            {
                'name': 'blammo',
                'level': 30,
                'msg': 'kaboom { bang: \'boom\', KABOOM: [Circular] }',
                'v': 0
            },
            {
                'name': 'blammo',
                'level': 30,
                'bang': 'boom',
                'KABOOM': {
                    'bang': 'boom',
                    'KABOOM': '[Circular]'
                },
                'msg': '',
                'v': 0
            }
        ];

var log = new Logger({
    name: 'blammo',
    streams: [
        {
            type: 'stream',
            level: 'info',
            stream: outstr
        }
    ]
});

test('cycles', function (t) {
    var rec;

    outstr.on('end', function () {
        output.forEach(function (o, i) {
            // Drop variable parts for comparison.
            delete o.hostname;
            delete o.pid;
            delete o.time;

            // In change https://github.com/nodejs/node/pull/27685 (part of
            // node v14), how objects with circular references are stringified
            // with `util.inspect` changed.
            if (Number(process.versions.node.split('.')[0]) >= 14) {
                expect[i].msg = expect[i].msg.replace(
                    // JSSTYLED
                    /{ bang: 'boom', KABOOM: \[Circular\] }/,
                    '<ref *1> { bang: \'boom\', KABOOM: [Circular *1] }'
                );
            }

            t.equal(JSON.stringify(o), JSON.stringify(expect[i]),
                'log record ' + i + ' matches');
        });
        t.end();
    });

    var obj = { bang: 'boom' };
    obj.KABOOM = obj;  // This creates a circular reference.

    log.info('bango', obj);
    log.info('kaboom', obj.KABOOM);
    log.info(obj);

    outstr.end();
    t.ok('did not throw');
});

==> node-bunyan_2.0.5+~cs4.4.3.orig.tar.gz: node-bunyan-2.0.5/test/cycles.test.js <==
/*
 * Copyright 2020 Trent Mick.
 *
 * Make sure cycles are safe.
 */

var Logger = require('../lib/bunyan.js');
var test = require('tap').test;


var Stream = require('stream').Stream;
var outstr = new Stream;
outstr.writable = true;
var output = [];
outstr.write = function (c) {
    output.push(JSON.parse(c + ''));
};
outstr.end = function (c) {
    if (c) this.write(c);
    this.emit('end');
};

var expect =
        [
            {
                'name': 'blammo',
                'level': 30,
                'msg': 'bango { bang: \'boom\', KABOOM: [Circular] }',
                'v': 0
            },
            {
                'name': 'blammo',
                'level': 30,
                'msg': 'kaboom { bang: \'boom\', KABOOM: [Circular] }',
                'v': 0
            },
            {
                'name': 'blammo',
                'level': 30,
                'bang': 'boom',
                'KABOOM': {
                    'bang': 'boom',
                    'KABOOM': '[Circular]'
                },
                'msg': '',
                'v': 0
            }
        ];

var log = new Logger({
    name: 'blammo',
    streams: [
        {
            type: 'stream',
            level: 'info',
            stream: outstr
        }
    ]
});

test('cycles', function (t) {
    var rec;

    outstr.on('end', function () {
        output.forEach(function (o, i) {
            // Drop variable parts for comparison.
            delete o.hostname;
            delete o.pid;
            delete o.time;

            // In change https://github.com/nodejs/node/pull/27685 (part of
            // node v14), how objects with circular references are stringified
            // with `util.inspect` changed.
            if (Number(process.versions.node.split('.')[0]) >= 14) {
                expect[i].msg = expect[i].msg.replace(
                    // JSSTYLED
                    /{ bang: 'boom', KABOOM: \[Circular\] }/,
                    '<ref *1> { bang: \'boom\', KABOOM: [Circular *1] }'
                );
            }

            t.equal(JSON.stringify(o), JSON.stringify(expect[i]),
                'log record ' + i + ' matches');
        });
        t.end();
    });

    var obj = { bang: 'boom' };
    obj.KABOOM = obj;  // This creates a circular reference.

    log.info('bango', obj);
    log.info('kaboom', obj.KABOOM);
    log.info(obj);

    t.ok('did not throw');

    outstr.end();
});
